=================================================
``psyclone.psyir.transformations.psy_data_trans``
=================================================

.. automodule:: psyclone.psyir.transformations.psy_data_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.transformations.psy_data_trans


Classes
=======

- :py:class:`PSyDataTrans`:
  Create a PSyData region around a list of statements. For


.. autoclass:: PSyDataTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: PSyDataTrans
      :parts: 1
